import pytest
import unittest

IPython = pytest.importorskip("IPython")

from PyFoam.IPythonHelpers.PermanentStorage import PermanentStorage
